Changelog
=================================================

v1.0.2
------
*    use sphinx for documentation
*    revise Jupyter notebooks

v1.0.1
------
*    trivial fix for release.txt
*    improve text
*    remove completed tasks
*    initial commit of 07-M2-Measurement.ipynb
*    bump version

v1.0.0
------
*    first pass at docs
*    General doc improvements
*    add routine to draw default figure
*    handle symmetric case dx=dy better
*    add new definitions and test dx=dy case

v0.2.0
------
*    initial commit
*    ensure float used for sums
*    first public release
